Enum grid_sdk::commits::store::StateChange [−][src]
A change that has been applied to state, represented in terms of a key/value pair
Variants
Fields of Delete
key: StringTrait Implementations
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.