InvalidArgumentError

Struct InvalidArgumentError 

pub struct InvalidArgumentError { /* private fields */ }
An error returned when an argument passed to a function does not conform to the expected format.

This always indicates a programming error on behalf of the caller, since the caller should have verified the argument prior to passing it into the function.

Implementations

Source

impl InvalidArgumentError

pub fn new(argument: String, message: String) -> Self

Constructs a new InvalidArgumentError with a specified argument and message string.

The argument passed in should be the name of the argument in the function’s signature. The message should be the reason it is invalid, and should not contain the name of the argument (since Display will combine both argument and message).

The implementation of std::fmt::Display for this error will be a combination of the argument and the message string provided.

Examples
use grid_sdk::error::InvalidArgumentError;

let invalid_arg_error = InvalidArgumentError::new("arg1".to_string(), "argument too long".to_string());
assert_eq!(format!("{}", invalid_arg_error), "argument too long (arg1)");
pub fn argument(&self) -> String

Returns the name of the invalid argument.

pub fn message(&self) -> String

Returns the message, which is an explanation of why the argument is invalid.