Role

Struct Role 

pub struct Role { /* private fields */ }
Native representation of a Role

A Role defines the permissions that are able to be assigned to an Organization’s Agent. This allows agents to perform actions defined within their role.

Implementations

Source

impl Role

pub fn org_id(&self) -> &str

pub fn name(&self) -> &str

pub fn description(&self) -> &str

pub fn active(&self) -> &bool

pub fn permissions(&self) -> &[String]

pub fn allowed_organizations(&self) -> &[String]

pub fn inherit_from(&self) -> &[String]