Struct grid_sdk::commits::store::CommitEvent [−][src]
pub struct CommitEvent {
pub service_id: Option<String>,
pub id: String,
pub height: Option<u64>,
pub state_changes: Vec<StateChange>,
}Fields
service_id: Option<String>An identifier for specifying where the event came from
id: StringAn identifier that is unique among events from the source
height: Option<u64>May be used to provide ordering of commits from the source. If None, ordering is not
explicitly provided, so it must be inferred from the order in which events are received.
state_changes: Vec<StateChange>All state changes that are included in the commit