Enum grid_sdk::error::ConstraintViolationType [−][src]
pub enum ConstraintViolationType {
Unique,
ForeignKey,
Other(String),
}Expand description
The type of constraint violation that caused the error
This is the type of constraint on the database’s definition that is violated. For example, if an operation tries to insert an entry that would cause a duplicate in a unique column, the ConstraintViolationType::Unique should be used.
Variants
Tuple Fields of Other
0: String