pub struct Role { /* private fields */ }Expand description
Native representation of a Role
A Role defines the permissions that are able to be assigned to an Organization’s Agent.
This allows agents to perform actions defined within their role.
Implementations