pub struct Proposal { /* private fields */ }Expand description
Native representation of a Proposal
A Proposal contains an offer from the owner or custodian of a Record to authorize another
agent a role, either owner, custodian, or reporter for the associated Record.
Implementations
Sourceimpl Proposal
impl Proposal
pub fn record_id(&self) -> &str
pub fn timestamp(&self) -> &u64
pub fn issuing_agent(&self) -> &str
pub fn receiving_agent(&self) -> &str
pub fn role(&self) -> &Role
pub fn properties(&self) -> &[String]
pub fn status(&self) -> &Status
pub fn terms(&self) -> &str
pub fn into_builder(self) -> ProposalBuilder