Module grid_sdk::store [−][src]
Enums
The possible connection types and identifiers for a StoreFactory
Traits
An abstract factory for creating Grid stores backed by the same storage
Functions
Creates a StoreFactory backed by the given connection